# frozen_string_literal: true

module Jekyll
  module LogAdapters
    # Provides a replacement for Stevenson to use the Test Anything
    # Protocol
    #
    # http://testanything.org/
    module Tap
      class Logger < Jekyll::Stevenson
        # TAP doesn't have that many levels, so we differentiate errors
        # from warnings by color and prefix.
        SEVERITY_FORMAT = {
          'DEBUG' => '#',
          'INFO'  => 'ok -'.green,
          'WARN'  => 'not ok - Warning:'.yellow,
          'ERROR' => 'not ok - Error:'.red,
          'FATAL' => 'Bail out!'.red,
          'ANY'   => ''
        }

        # Replace the formatter with a proc
        #
        # Multi-line messages are assumed to be debug level, like the
        # profiler table.
        def initialize
          super

          @formatter = proc do |severity, _, _, msg|
            msg = msg.to_s.strip_ansi.strip

            next if msg.empty?

            if msg.lines.size > 1
              msg.lines.map do |line|
                "#{SEVERITY_FORMAT['DEBUG']} #{line}"
              end.join
            else
              "#{SEVERITY_FORMAT[severity]} #{msg}"
            end
          end
        end
      end
    end
  end
end
